# circle-developer-controlled-wallets
This SDK provides convenient access to Circle's Developer Controlled Wallets APIs for applications written in Python. For the API reference, see the [Circle Web3 API docs](https://developers.circle.com/api-reference/w3s/common/ping).

- Package version: 5.3.0

## Requirements.

Python 3.7+

## Installation
### pip install

```sh
pip install circle-developer-controlled-wallets
```

Then import the package:
```python
from circle.web3 import developer_controlled_wallets
```


## Usage

1. Generate an API key, if you haven't already, in the [Web3 Services Console](https://console.circle.com/api-keys). This API key will be used for authentication and authorization when making requests to Circle's APIs.

    ```sh
    export CIRCLE_WEB3_API_KEY="Your API KEY"
    ```

2. Generate a new entity secret by using the helper function in the SDK. This will print a new entity secret which will be used in step 3 to register it. 

    ```python
    from circle.web3 import utils

    utils.generate_entity_secret()
    ```

    > [!IMPORTANT]  
    Protect your Entity Secret as you would protect your house key. Losing it or sharing it with others can have serious consequences. As the name suggests, the Entity Secret is sensitive information. Store it securely and treat it with the highest level of confidentiality to prevent unauthorized access or use.

3. Register the entity secret either by using the SDK or by following Circle's [Developer-Controlled QuickStart](https://developers.circle.com/interactive-quickstarts/dev-controlled-wallets#setup-your-entity-secret). This step ensures that your account is correctly set up to interact with Circle's APIs.

    ```python
        from circle.web3 import utils
        result =  utils.register_entity_secret_ciphertext(api_key='your_api_key', entity_secret='new_entity_secret')
        print(result)
    ```
    > [!IMPORTANT] 
    The `register_entity_secret_ciphertext` function downloads a recovery file named `recovery_file_<timestamp>.dat`. This file should be stored securely, similar to the entity secret. Additionally, the function returns the content of the recovery file as a JSON response. 

4. In your code, use the `init_developer_controlled_wallets_client` function from the utils and initialize the client using your API key and entity secret:

    ```python
    from circle.web3 import utils

    client = utils.init_developer_controlled_wallets_client(api_key="Your API KEY", entity_secret="Your entity secret")
    ```

5. Interact with the client:

```python
from circle.web3 import utils
from circle.web3 import developer_controlled_wallets

client = utils.init_developer_controlled_wallets_client(api_key="Your API KEY", entity_secret="Your entity secret")
api_instance = developer_controlled_wallets.WalletSetsApi(client)

# create wallet sets
try:
    request = developer_controlled_wallets.CreateWalletSetRequest.from_dict({
        "name": "my_wallet_set"
    })
    response = api_instance.create_wallet_set(request)
    print(response)
except developer_controlled_wallets.ApiException as e:
    print("Exception when calling WalletSetsApi->create_wallet_set: %s\n" % e)

# list wallet sets
try:
    response = api_instance.get_wallet_sets()
    for wallet_set in response.data.wallet_sets:
        print(wallet_set.actual_instance.id)
except developer_controlled_wallets.ApiException as e:
    print("Exception when calling WalletSetsApi->get_wallet_sets: %s\n" % e)
```

We recommend reading through the official [documentation](https://developers.circle.com/w3s/docs) and [QuickStart guides](https://developers.circle.com/interactive-quickstarts) mentioned above to ensure a smooth setup and usage experience.


## Configuration

The client accept following configuration parameters:

Option | Required | Description
------------ | ------------- | -------------
api_key | Yes | Api Key that is used to authenticate against Circle APIs. Must be provided by ether env variable or function parameter
entity_secret | Yes | Your configured entity secret. Must be provided by ether env variable or function parameter.
host | No | Optional base URL to override the default: https://api.circle.com/v1/w3s.
user_agent | No | Optional custom user agent request header. We will prepend it to default user agent header if provided.


## Need help or have questions?

Here are some helpful links, if you encounter any issues or have questions about this SDK:

- 📖 [Getting started](https://developers.circle.com/interactive-quickstarts/dev-controlled-wallets): Check out our official Developer-Controlled Wallets QuickStart.
- 🎮 [Join our Discord Community](https://discord.com/invite/buildoncircle): Engage, learn, and collaborate.
- 🛎 [Visit our Help-Desk Page](https://support.usdc.circle.com/hc/en-us/p/contactus?_gl=1*1va6vat*_ga*MTAyNTA0NTQ2NC4xNjk5NTYyMjgx*_ga_GJDVPCQNRV*MTcwMDQ5Mzg3Ny4xNC4xLjE3MDA0OTM4ODQuNTMuMC4w): Dive into curated FAQs and guides.
- 📧 [Direct Email](mailto:customer-support@circle.com): We're always a message away.
- 📖 [Read docs](https://developers.circle.com/w3s/docs?_gl=1*15ozb5b*_ga*MTAyNTA0NTQ2NC4xNjk5NTYyMjgx*_ga_GJDVPCQNRV*MTcwMDQ5Mzg3Ny4xNC4xLjE3MDA0OTM4ODQuNTMuMC4w): Check out our developer documentation.
Happy coding!
